Struct openvet_common::rust::CrateVersion
source · pub struct CrateVersion {
pub krate: CrateName,
pub version: Version,
}Fields
krate: CrateNameversion: VersionTrait Implementations
sourceimpl Arbitrary for CrateVersion
impl Arbitrary for CrateVersion
type Parameters = ()
type Parameters = ()
The type of parameters that
arbitrary_with accepts for configuration
of the generated Strategy. Parameters must implement Default.type Strategy = BoxedStrategy<CrateVersion>
type Strategy = BoxedStrategy<CrateVersion>
The type of
Strategy used to generate values of type Self.sourcefn arbitrary_with(args: <Self as Arbitrary>::Parameters) -> Self::Strategy
fn arbitrary_with(args: <Self as Arbitrary>::Parameters) -> Self::Strategy
sourceimpl Clone for CrateVersion
impl Clone for CrateVersion
sourcefn clone(&self) -> CrateVersion
fn clone(&self) -> CrateVersion
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for CrateVersion
impl Debug for CrateVersion
sourceimpl<'de> Deserialize<'de> for CrateVersion
impl<'de> Deserialize<'de> for CrateVersion
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for CrateVersion
impl Hash for CrateVersion
sourceimpl Ord for CrateVersion
impl Ord for CrateVersion
sourcefn cmp(&self, other: &CrateVersion) -> Ordering
fn cmp(&self, other: &CrateVersion) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for CrateVersion
impl PartialEq for CrateVersion
sourcefn eq(&self, other: &CrateVersion) -> bool
fn eq(&self, other: &CrateVersion) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for CrateVersion
impl PartialOrd for CrateVersion
sourcefn partial_cmp(&self, other: &CrateVersion) -> Option<Ordering>
fn partial_cmp(&self, other: &CrateVersion) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for CrateVersion
impl Serialize for CrateVersion
impl Eq for CrateVersion
impl StructuralPartialEq for CrateVersion